==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TemplateHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellInfoDescriptionMetadata } from "./TemplateCellInfoDescriptionMetadata";
import { TemplateHeaderCellInfoDescription } from "./TemplateHeaderCellInfoDescription";
/**
 * @hidden
 */
var TemplateHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateHeaderCellInfoDescriptionMetadata, _super);
    function TemplateHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateHeaderCellInfoDescriptionMetadata.a == null) {
            TemplateHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateHeaderCellInfoDescriptionMetadata.c(TemplateHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.j(TemplateHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateHeaderCellInfoDescriptionMetadata.c = function (a) {
        TemplateCellInfoDescriptionMetadata.c(a);
        a.item("IsFilterUIVisible", "Boolean");
    };
    TemplateHeaderCellInfoDescriptionMetadata.d = function (a) {
        TemplateHeaderCellInfoDescriptionMetadata.b(a);
        a.aa("TemplateHeaderCellInfo", function () { return new TemplateHeaderCellInfoDescription(); });
        a.z("TemplateHeaderCellInfo", TemplateHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateHeaderCellInfoDescriptionMetadata.$t = markType(TemplateHeaderCellInfoDescriptionMetadata, 'TemplateHeaderCellInfoDescriptionMetadata');
    TemplateHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateHeaderCellInfoDescriptionMetadata;
}(Base));
export { TemplateHeaderCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TemplateHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateCellInfoDescriptionMetadata } from "./TemplateCellInfoDescriptionMetadata";
import { TemplateHeaderCellInfoDescription } from "./TemplateHeaderCellInfoDescription";
/**
 * @hidden
 */
var TemplateHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateHeaderCellInfoDescriptionMetadata, _super);
    function TemplateHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateHeaderCellInfoDescriptionMetadata.a == null) {
            TemplateHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateHeaderCellInfoDescriptionMetadata.c(TemplateHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.k(TemplateHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.aa(TemplateHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateHeaderCellInfoDescriptionMetadata.c = function (a) {
        TemplateCellInfoDescriptionMetadata.c(a);
        a.item("IsFilterUIVisible", "Boolean");
    };
    TemplateHeaderCellInfoDescriptionMetadata.d = function (a) {
        TemplateHeaderCellInfoDescriptionMetadata.b(a);
        a.ac("TemplateHeaderCellInfo", function () { return new TemplateHeaderCellInfoDescription(); });
        a.ab("TemplateHeaderCellInfo", TemplateHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateHeaderCellInfoDescriptionMetadata.$t = markType(TemplateHeaderCellInfoDescriptionMetadata, 'TemplateHeaderCellInfoDescriptionMetadata');
    TemplateHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateHeaderCellInfoDescriptionMetadata;
}(Base));
export { TemplateHeaderCellInfoDescriptionMetadata };
